# fabrictestbed-extensions

Extensions for the FABRIC API/CLI.  

## Install Instructions
```
git clone https://github.com/fabric-testbed/fabrictestbed-extensions.git 
cd fabrictestbed-extensions
pip install --user .
```
